==> OpenViewerFX-6.6.14-sources.jar: org/jpedal/examples/viewer/gui/javafx/JavaFXCursor.java <==
/*
 * ===========================================
 * Java Pdf Extraction Decoding Access Library
 * ===========================================
 *
 * Project Info:  http://www.idrsolutions.com
 * Help section for developers at http://www.idrsolutions.com/support/
 *
 * (C) Copyright 1997-2015 IDRsolutions and Contributors.
 *
 * This file is part of JPedal/JPDF2HTML5
 *
     This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


 *
 * ---------------
 * JavaFXCursor.java
 * ---------------
 */

package org.jpedal.examples.viewer.gui.javafx;

import java.net.URL;
import javafx.scene.Cursor;
import javafx.scene.image.Image;

/**
 * This class controls everything todo with JavaFX Cursor objects
 */
public class JavaFXCursor {

    /** grabbing cursor
    private Cursor grabCursor;
    private Cursor grabbingCursor;
    private Cursor panCursor;
    private Cursor panCursorL;
    private Cursor panCursorTL;
    private Cursor panCursorT;
    private Cursor panCursorTR;
    private Cursor panCursorR;
    private Cursor panCursorBR;
    private Cursor panCursorB;
    private Cursor panCursorBL;
    /**/
    
    public static Cursor getCursor(final int type) {
        System.out.println("Method getCursor in JavaFXCursor.java is not implemented for JavaFX");
        return null;
    }
    
    public static URL getURLForImage(final String path){
        System.out.println("Method getURLForImage in JavaFXCursor.java is not implemented for JavaFX");
        return null;
    }
    
    public static Image getCursorImageForFX(final int type) {
        System.out.println("Method getURLForImage in JavaFXCursor.java is not implemented for JavaFX");
        return null;
    }
    
    
}

==> OpenViewerFX-7.9.26-sources.jar: org/jpedal/examples/viewer/gui/javafx/JavaFXCursor.java <==
/*
 * ===========================================
 * Java Pdf Extraction Decoding Access Library
 * ===========================================
 *
 * Project Info:  http://www.idrsolutions.com
 * Help section for developers at http://www.idrsolutions.com/support/
 *
 * (C) Copyright 1997-2017 IDRsolutions and Contributors.
 *
 * This file is part of JPedal/JPDF2HTML5
 *
     This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


 *
 * ---------------
 * JavaFXCursor.java
 * ---------------
 */

package org.jpedal.examples.viewer.gui.javafx;

import java.net.URL;
import javafx.scene.Cursor;
import javafx.scene.image.Image;

/**
 * This class controls everything todo with JavaFX Cursor objects
 */
public class JavaFXCursor {

    /** grabbing cursor
    private Cursor grabCursor;
    private Cursor grabbingCursor;
    private Cursor panCursor;
    private Cursor panCursorL;
    private Cursor panCursorTL;
    private Cursor panCursorT;
    private Cursor panCursorTR;
    private Cursor panCursorR;
    private Cursor panCursorBR;
    private Cursor panCursorB;
    private Cursor panCursorBL;
    /**/
    
    public static Cursor getCursor(final int type) {
        System.out.println("Method getCursor in JavaFXCursor.java is not implemented for JavaFX "+type);
        return null;
    }
    
    public static URL getURLForImage(final String path){
        System.out.println("Method getURLForImage in JavaFXCursor.java is not implemented for JavaFX "+path);
        return null;
    }
    
    public static Image getCursorImageForFX(final int type) {
        System.out.println("Method getURLForImage in JavaFXCursor.java is not implemented for JavaFX "+type);
        return null;
    }
    
    
}
